@@ -1,9 +1,10 @@
 package App::Greple::xlate::gpt3;
 
-our $VERSION = "0.27";
+our $VERSION = "0.28";
 
 use v5.14;
 use warnings;
+use utf8;
 use Encode;
 use Data::Dumper;
 
@@ -33,6 +34,7 @@ sub gpty {
 	-t => $param->{temp},
 	$prompt, '-',
     );
+    warn Dumper \@command if opt('debug');
     $gpty->command(\@command)->setstdin(+shift)->update->data;
 }
 
